@@ -13,28 +13,30 @@ class AuditStatus(Enum):
         return self.value
 
 
-class AuditLog:
-    def __init__(self, actor_id: str, scope: str, reference: str):
-        self.log_id = str(Guid())
+class AuditEntry:
+    def __init__(self, actor_id: str, scope: str):
+        self.entry_id = str(Guid())
         self.actor_id = actor_id
         self.scope = scope
-        self.reference = reference
         self.status = AuditStatus.FAILED
         self.created_on = datetime.utcnow()
 
+    def __str__(self) -> str:
+        return f"[{self.created_on.isoformat()}] {self.actor_id} -> {self.scope} - {self.status}"
+
 
 @runtime_checkable
 class AuditStore(Protocol):
     @abstractmethod
-    def append(self, log: AuditLog) -> None:
+    def append(self, log: AuditEntry) -> None:
         ...
 
 
 class InMemoryAuditStore(AuditStore):
     def __init__(self):
-        self._log: List[AuditLog] = []
+        self._log: List[AuditEntry] = []
 
-    def append(self, log: AuditLog) -> None:
+    def append(self, log: AuditEntry) -> None:
         self._log.append(log)
 
     def __getitem__(self, item):
